% Aerodynamic ROM for the scaled-up (x20) OAT15A airfoil, predicting the incremental lift from an oscillating aileron at various deflection frequencies and amplitudes.
% Author:  Paul Lancelot
% Model used in the following thesis: Lancelot, P. M. G. J. (2023). Transonic Wing and Control Surface Loads Modelling for Aeroservoelastic Analysis. https://doi.org/10.4233/uuid:e37566e8-cb46-4f90-863d-9cfe0b634507
% Contact: pmgj.lancelot@gmail.com
%%%%%% Model information %%%%%%%
% The training and validation reference RANS-CFD data are generated with Ansys Fluent with k-w SST turbulence model. 
% Mach 0.73
% Airfoil chord length is 3m
% Airfoil angle of attack set to 0deg
% Dynamic pressure of 20500Pa
% CFD simulation time step of 0.0025sec
% In Figure 3.10, the lift from both the aerodynamic model and the reference RANS-CFD are normalized with the same abritrary value of 7.1. For other 2D applications, please normalize with the chord length instead.
% Improvements were made to the aerodynamic look-up table and to the transfer function identification process, therefore the figure produced by this script slightly differs from Figure 3.10.


clear all
load('Data_ROM_and_CFD_validation.mat')

% Do you want to re-identify the unsteady transfer function?
TF_ident = 0

if TF_ident == 1
load('Training_data.mat')
sysdata = iddata(CFD_lift_for_ident-Quasi_steady_lift,Disp,0.005);
TF = tfest(sysdata,2,2)
end


% This replicates the figure 3.10 of the dissertation
figure(1)

for i = 1:20
amp = Amplitude(i)/180*pi
freq = Frequency(i)
options = simset('SrcWorkspace','current');

% run the Simulink model
sim('ROM_aileron_Simulink_unsteady_NL_lift',[],options);
subplot(5,4,i)

yplot=CFD_ref_Lift(:,i)/(20500*7.1);              % make a copy of the data specifically for plotting
yplot(yplot==0)=nan;                                           % replace 0 elements with NaN

plot(disp(1:length(yplot),2),yplot-CFD_ref_Lift(20,i)/(20500*7.1),'b-')
hold all
plot(disp(1:end,2),unsteady_non_linear_lift(1:end,2)/(20500*7.1),'r-')
%plot(disp(1:end,2),quasi_steady_lift_component(1:end,2)/(20500*7.1),'g-')
%plot(disp(1:end,2),linear_lift(1:end,2)/(20500*7.1),'k:')

max_speed(i) = max(speed(:,2))
end

% add legend
legend('RANS-CFD','Aero ROM')
Lgnd = legend('show');
Lgnd.Position(1) = 0.8;
Lgnd.Position(2) = 0.9;
